ExternalStorageLayout

Type Alias ExternalStorageLayout 

type ExternalStorageLayout = Option<(String, Arc<StorageLayout>)>;
A resolved storage layout, or None if the contract has no layout we can use.

A None means the lookup concluded that there is nothing to decode with: the contract is unverified, is Vyper, failed to compile, or compiled to an empty layout. It is memoized for the rest of the run.

Aliased Type

enum ExternalStorageLayout {
    None,
    Some((String, Arc<StorageLayout>)),
}

Variants

1.0.0

None

No value.

1.0.0

Some((String, Arc<StorageLayout>))

Some value of type T.

Layout

Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.