LookupSlot

Type Alias LookupSlot 

type LookupSlot = Arc<Mutex<Option<Option<(String, Arc<StorageLayout>)>>>>;
A single address’ lookup slot: None until the lookup completes, then its memoized result.

Aliased Type

struct LookupSlot { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 8 bytes