type ExternalStorageLayout = Option<(String, Arc<StorageLayout>)>;Expand description
A resolved storage layout, or None if the contract has no layout we can use.
A None means the lookup concluded that there is nothing to decode with: the contract is
unverified, is Vyper, failed to compile, or compiled to an empty layout. It is memoized for
the rest of the run.
Aliased Type
enum ExternalStorageLayout {
None,
Some((String, Arc<StorageLayout>)),
}Variants
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.